@@ -3,10 +3,8 @@
 use strict;
 use warnings;
 package Alien::OTR;
-BEGIN {
-  $Alien::OTR::AUTHORITY = 'cpan:AJGB';
-}
-$Alien::OTR::VERSION = '4.1.0.0';
+our $AUTHORITY = 'cpan:AJGB';
+$Alien::OTR::VERSION = '4.1.1.0';
 use Alien::GCrypt;
 use Alien::GPG::Error;
 
@@ -26,7 +24,7 @@ Alien::OTR - Install and make available libotr v4 library
 
 =head1 VERSION
 
-version 4.1.0.0
+version 4.1.1.0
 
 =head1 SYNOPSIS
 
@@ -37,7 +35,7 @@ version 4.1.0.0
 
 =head1 DESCRIPTION
 
-Alien::OTR installs the C library C<libotr> version v4.1.0.
+Alien::OTR installs the C library C<libotr> version v4.1.1.
 
 =head1 SEE ALSO
 
@@ -53,7 +51,7 @@ Alex J. G. Burzyński <ajgb@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Alex J. G. Burzyński <ajgb@cpan.org>.
+This software is copyright (c) 2016 by Alex J. G. Burzyński <ajgb@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
